@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: messageManager.php 3808 2010-11-12 06:31:15Z fishbone $
+ * @version    SVN: $Id: messageManager.php 5414 2012-11-27 02:46:34Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -32,6 +32,7 @@ class MessageManager extends Core
 	const MSG_ACCESS_DENY = 'msg_access_deny';							// アクセス不可メッセージ
 	const DEFAULT_MSG_SITE_IN_MAINTENANCE = 'ただいまサイトのメンテナンス中です';// サイトメンテナンス中メッセージのデフォルト値
 	const DEFAULT_MSG_ACCESS_DENY = 'アクセスできません';						// アクセス不可メッセージのデフォルト値
+	const DEFAULT_WORD_UNTITLED = '[未設定]';		// 用語未設定
 	const LOCALE_TEXT_FILE_GETTEXT = '/php-gettext-1.0.10/gettext.php';			// 各言語対応テキスト処理用
 	const LOCALE_TEXT_FILE_STREAMS = '/php-gettext-1.0.10/streams.php';			// 各言語対応テキスト処理用
 	
@@ -252,5 +253,23 @@ class MessageManager extends Core
 		}
 		return $dest;
 	}
+	/**
+	 * 用語定義値を取得
+	 *
+	 * @param string $key    キーとなる項目値
+	 * @param string $lang	言語ID(空の場合は現在の言語ID)
+	 * @return string		値
+	 */
+	function getWord($key, $lang = '')
+	{
+		if (empty($lang)) $lang = $this->gEnv->getCurrentLanguage();
+		
+		// 初期データ読み込み
+		$this->_loadLangString($lang);
+		
+		$value = $this->_langStringArray[$key];
+		if (!isset($value)) $value = self::DEFAULT_WORD_UNTITLED;		// 用語未設定
+		return $value;
+	}
 }
 ?>
