@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_dispProductWidgetContainer.php 5419 2012-11-30 05:06:11Z fishbone $
+ * @version    SVN: $Id: ec_dispProductWidgetContainer.php 5472 2012-12-17 07:09:37Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -34,6 +34,9 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 	private $ecObj;					// EC共通ライブラリオブジェクト
 	private $showStock;				// 在庫表示するかどうか
 	private $contentNoStock;		// 在庫なし時コンテンツ
+	private $headTitle;		// METAタグタイトル
+	private $headDesc;		// METAタグ要約
+	private $headKeyword;	// METAタグキーワード
 	const PRICE_OBJ_ID = "eclib";		// 価格計算オブジェクトID
 	const STANDARD_PRICE = 'selling';		// 通常価格
 	const PRODUCT_IMAGE_MEDIUM = 'standard-product';		// 中サイズ商品画像ID
@@ -381,6 +384,9 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				$description = $row['pt_description'];			// 説明
 				$description_short = $row['pt_description_short'];		// 簡易説明
 				//$keyword = $row['pt_search_keyword'];					// 検索キーワード
+				$this->headTitle = $row['pt_name'];		// METAタグタイトル
+				$this->headDesc = $row['pt_description_short'];		// METAタグ要約
+				$this->headKeyword = $row['pt_meta_keywords'];			// METAタグキーワード
 				$url = $row['pt_site_url'];							// 詳細情報URL
 				$this->taxType = $row['pt_tax_type_id'];					// 税種別
 				//$adminNote = $row['pt_admin_note'];		// 管理者用備考
@@ -503,6 +509,23 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 			}
 		}
 	}
+	/**
+	 * ヘッダ部メタタグの設定
+	 *
+	 * HTMLのheadタグ内に出力する。
+	 * _assign()よりも後に実行される。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ
+	 * @return array 						設定データ。連想配列で「title」「description」「keywords」を設定。
+	 */
+	function _setHeadMeta($request, &$param)
+	{
+		$headData = array(	'title' => $this->headTitle,
+							'description' => $this->headDesc,
+							'keywords' => $this->headKeyword);
+		return $headData;
+	}
 	/**
 	 * 取得したデータをテンプレートに設定する
 	 *
