@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainConfirmWidgetContainer.php 5440 2012-12-08 09:37:39Z fishbone $
+ * @version    SVN: $Id: ec_mainConfirmWidgetContainer.php 5453 2012-12-09 12:27:50Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/ec_mainBaseWidgetContainer.php');
@@ -99,6 +99,11 @@ class ec_mainConfirmWidgetContainer extends ec_mainBaseWidgetContainer
 				// ##### 注文書データエラーチェック #####
 				$this->checkInput($row['oe_pay_method_id'], 'お支払い方法', 'お支払い方法が選択されていません');		// 支払方法は必須入力
 
+				// カートの商品の在庫数をチェック
+				$this->_checkCart = true;			// カート内容のエラーチェックかどうか
+				$this->_getCartItems('_defaultCartLoop');
+				$this->_checkCart = false;			// カート内容のエラーチェックかどうか
+				
 				// エラーなしの場合は受注登録処理
 				if ($this->getMsgCount() == 0){
 					// 受注No作成
@@ -354,12 +359,16 @@ class ec_mainConfirmWidgetContainer extends ec_mainBaseWidgetContainer
 					$msg = 'ご購入ありがとうございました。';
 					//$this->tmpl->addVar("_widget", "message_top", $msg);		// メッセージ
 				} else {
-					$msg = 'ご注文を確定してください。';
-					if ($isOnlinePayment) $msg .= '注文確定後、お支払い画面へ遷移します。';
-					//$this->tmpl->addVar("_widget", "message_top", $msg);		// メッセージ
+					// 在庫数の確認
+					if ($this->getMsgCount() == 0){		// 注文分の在庫がある場合
+						$msg = 'ご注文を確定してください。';
+						if ($isOnlinePayment) $msg .= '注文確定後、お支払い画面へ遷移します。';
+						//$this->tmpl->addVar("_widget", "message_top", $msg);		// メッセージ
 					
-					// カートに商品がある場合は、確認ボタンを表示
-					if ($this->_productExists) $this->tmpl->setAttribute('show_confirm', 'visibility', 'visible');
+						// カートに商品がある場合は、確認ボタンを表示
+						if ($this->_productExists) $this->tmpl->setAttribute('show_confirm', 'visibility', 'visible');
+					}
+					$this->tmpl->setAttribute('show_back', 'visibility', 'visible');// 戻るボタン表示
 				}
 			} else {		// 注文書が取得できない場合はエラー画面へ遷移
 				$errPage = $this->gEnv->createCurrentPageUrl() . '&task=' . self::ERROR_TASK;
